@@ -31,16 +31,24 @@ import org.gnu.gtk.event.AdjustmentListener;
 import org.gnu.gtk.event.ButtonListener;
 import org.gnu.gtk.event.CalendarListener;
 import org.gnu.gtk.event.CellRendererTextListener;
+import org.gnu.gtk.event.CheckMenuItemListener;
+import org.gnu.gtk.event.ColorButtonListener;
+import org.gnu.gtk.event.ComboBoxListener;
 import org.gnu.gtk.event.ContainerListener;
 import org.gnu.gtk.event.DialogListener;
 import org.gnu.gtk.event.EntryListener;
+import org.gnu.gtk.event.ExpanderListener;
+import org.gnu.gtk.event.ExposeListener;
 import org.gnu.gtk.event.FocusListener;
+import org.gnu.gtk.event.FontButtonListener;
 import org.gnu.gtk.event.GtkEvent;
 import org.gnu.gtk.event.GtkEventType;
+import org.gnu.gtk.event.ItemListener;
 import org.gnu.gtk.event.KeyListener;
 import org.gnu.gtk.event.LifeCycleListener;
 import org.gnu.gtk.event.MenuItemListener;
 import org.gnu.gtk.event.MouseListener;
+import org.gnu.gtk.event.MouseMotionListener;
 import org.gnu.gtk.event.NotebookListener;
 import org.gnu.gtk.event.OptionMenuListener;
 import org.gnu.gtk.event.RangeListener;
@@ -49,10 +57,11 @@ import org.gnu.gtk.event.SpinListener;
 import org.gnu.gtk.event.TextBufferListener;
 import org.gnu.gtk.event.TextViewListener;
 import org.gnu.gtk.event.ToggleListener;
+import org.gnu.gtk.event.ToolBarListener;
 import org.gnu.gtk.event.ToolButtonListener;
+import org.gnu.gtk.event.TreeModelListener;
 import org.gnu.gtk.event.TreeSelectionListener;
 import org.gnu.gtk.event.TreeViewColumnListener;
-import org.gnu.gtk.event.TreeViewListener;
 
 abstract class ListenerDelegate {
 
@@ -154,24 +163,36 @@ abstract class ListenerDelegate {
 		delegateMap.put(ButtonListener.class, ButtonDelegate.class);
 		delegateMap.put(CalendarListener.class, CalendarDelegate.class);
 		delegateMap.put(CellRendererTextListener.class, CellRendererTextDelegate.class);
+		delegateMap.put(CheckMenuItemListener.class, CheckMenuItemDelegate.class);
+		delegateMap.put(ColorButtonListener.class, ColorButtonDelegate.class);
+		delegateMap.put(ComboBoxListener.class, ComboBoxDelegate.class);
 		delegateMap.put(ContainerListener.class, ContainerDelegate.class);
 		delegateMap.put(DialogListener.class, DialogDelegate.class);
 		delegateMap.put(EntryListener.class, EntryDelegate.class);
+		delegateMap.put(ExpanderListener.class, ExpanderDelegate.class);
+		delegateMap.put(ExposeListener.class, ExposeDelegate.class);
 		delegateMap.put(FocusListener.class, FocusDelegate.class);
+		delegateMap.put(FontButtonListener.class, FontButtonDelegate.class);
+		delegateMap.put(ItemListener.class, ItemDelegate.class);
 		delegateMap.put(KeyListener.class, KeyDelegate.class);
 		delegateMap.put(LifeCycleListener.class, LifeCycleDelegate.class);
 		delegateMap.put(MenuItemListener.class, MenuItemDelegate.class);
 		delegateMap.put(MouseListener.class, MouseDelegate.class);
+		delegateMap.put(MouseMotionListener.class, MouseMotionDelegate.class);
 		delegateMap.put(NotebookListener.class, NotebookDelegate.class);
 		delegateMap.put(OptionMenuListener.class, OptionMenuDelegate.class);
 		delegateMap.put(RangeListener.class, RangeDelegate.class);
 		delegateMap.put(ScaleListener.class, ScaleDelegate.class);
 		delegateMap.put(SpinListener.class, SpinDelegate.class);
 		delegateMap.put(TextBufferListener.class, TextBufferDelegate.class);
-		delegateMap.put(TextViewListener.class, TextViewDelegate.class);
 		delegateMap.put(ToggleListener.class, ToggleDelegate.class);
+		delegateMap.put(ToolBarListener.class, ToolBarDelegate.class);
+		delegateMap.put(ToolButtonListener.class, ToolButtonDelegate.class);
+		delegateMap.put(TreeModelListener.class, TreeModelDelegate.class);
 		delegateMap.put(TreeSelectionListener.class, TreeSelectionDelegate.class);
 		delegateMap.put(TreeViewColumnListener.class, TreeViewColumnDelegate.class);
+		delegateMap.put(TextViewListener.class, TextViewDelegate.class);
+
 		delegateMap.put(AppBarListener.class, AppBarDelegate.class);
 		delegateMap.put(ClientListener.class, ClientDelegate.class);
 		delegateMap.put(ColorPickerListener.class, ColorPickerDelegate.class);
@@ -179,7 +200,5 @@ abstract class ListenerDelegate {
 		delegateMap.put(DruidPageChangeListener.class, DruidPageDelegate.class);
 		delegateMap.put(DruidPageSetupListener.class, DruidPageDelegate.class);
 		delegateMap.put(FontPickerListener.class, FontPickerDelegate.class);
-		delegateMap.put(TreeViewListener.class, TreeViewDelegate.class);
-		delegateMap.put(ToolButtonListener.class, ToolButtonDelegate.class);
 	}
 }
